@@ -216,6 +216,16 @@ def populate_azure_snapshot(snapshot, container=None, snapshot_type='azure'):
                                         ('timestamp', pymongo.DESCENDING)
                                     ]
                                 )
+
+                                create_indexes(
+                                    data['collection'], 
+                                    config_value(DATABASE, DBNAME), 
+                                    [
+                                        ('_id', pymongo.DESCENDING),
+                                        ('timestamp', pymongo.DESCENDING),
+                                        ('snapshotId', pymongo.ASCENDING)
+                                    ]
+                                )
                             insert_one_document(data, data['collection'], dbname)
                         else:
                             snapshot_dir = make_snapshots_dir(container)
