@@ -408,6 +408,15 @@ def populate_google_snapshot(snapshot, container=None):
                                             ('timestamp', pymongo.DESCENDING)
                                         ]
                                     )
+                                    create_indexes(
+                                        data['collection'], 
+                                        config_value(DATABASE, DBNAME), 
+                                        [
+                                            ('_id', pymongo.DESCENDING),
+                                            ('timestamp', pymongo.DESCENDING),
+                                            ('snapshotId', pymongo.ASCENDING)
+                                        ]
+                                    )
                                 insert_one_document(data, data['collection'], dbname)
                             else:
                                 snapshot_dir = make_snapshots_dir(container)
